@@ -10,7 +10,7 @@ summary.mnp <- function(object, CI=c(2.5, 97.5),...){
   colnames(param.table) <- c("mean", "std.dev.", paste(min(CI), "%", sep=""),
                              paste(max(CI), "%", sep=""))
   
-  ans <- list(call=object$call, n.alt=p, n.obs=if(is.matrix(object$y))
+  ans <- list(call=object$call, base = object$base, n.alt=p, n.obs=if(is.matrix(object$y))
               nrow(object$y) else length(object$y), n.draws = n.draws,
               coef.table=param.table[1:n.cov,],
               cov.table=param.table[(n.cov+1):ncol(param),])  
